@@ -206,55 +206,6 @@ force_no_pixmap_background (GtkWidget *widget)
         gtk_widget_set_name (widget, "gs-window-drawing-area");
 }
 
-static void
-clear_children (Window window)
-{
-        Window            root;
-        Window            parent;
-        Window           *children;
-        unsigned int      n_children;
-        int               status;
-
-        children = NULL;
-        status = XQueryTree (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), window, &root, &parent, &children, &n_children);
-
-        if (status == 0) {
-                if (children) {
-                        XFree (children);
-                }
-                return;
-        }
-
-        if (children) {
-                while (n_children) {
-                        Window child;
-
-                        child = children [--n_children];
-
-                        XClearWindow (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), child);
-                        clear_children (child);
-                }
-
-                XFree (children);
-        }
-}
-
-static void
-widget_clear_all_children (GtkWidget *widget)
-{
-        GdkWindow *w;
-
-        gs_debug ("Clearing all child windows");
-
-        gdk_error_trap_push ();
-
-        w = gtk_widget_get_window (widget);
-
-        clear_children (GDK_WINDOW_XID (w));
-
-        gdk_error_trap_pop_ignored ();
-}
-
 static void
 gs_window_reset_background_surface (GSWindow *window)
 {
@@ -2086,6 +2037,30 @@ gs_window_real_size_request (GtkWidget      *widget,
         gs_window_move_resize_window (window, position_changed, size_changed);
 }
 
+static void
+gs_window_real_get_preferred_width (GtkWidget *widget,
+                                    gint      *minimum,
+                                    gint      *natural)
+{
+  GtkRequisition requisition;
+
+  gs_window_real_size_request (widget, &requisition);
+
+  *minimum = *natural = requisition.width;
+}
+
+static void
+gs_window_real_get_preferred_height (GtkWidget *widget,
+                                     gint      *minimum,
+                                     gint      *natural)
+{
+  GtkRequisition requisition;
+
+  gs_window_real_size_request (widget, &requisition);
+
+  *minimum = *natural = requisition.height;
+}
+
 static gboolean
 gs_window_real_grab_broken (GtkWidget          *widget,
                             GdkEventGrabBroken *event)
@@ -2170,7 +2145,8 @@ gs_window_class_init (GSWindowClass *klass)
         widget_class->motion_notify_event = gs_window_real_motion_notify_event;
         widget_class->button_press_event  = gs_window_real_button_press_event;
         widget_class->scroll_event        = gs_window_real_scroll_event;
-        widget_class->size_request        = gs_window_real_size_request;
+        widget_class->get_preferred_width = gs_window_real_get_preferred_width;
+        widget_class->get_preferred_height= gs_window_real_get_preferred_height;
         widget_class->grab_broken_event   = gs_window_real_grab_broken;
         widget_class->visibility_notify_event = gs_window_real_visibility_notify_event;
 
